Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProgressBarConfig ¶
func ProgressBarConfig(bar *pb.ProgressBar, prefix string)
Types ¶
type BaseConfig ¶
type BaseConfig struct {
Root string `mapstructure:"root", hcl:"root"`
}
BaseConfig defines the top level or "root" config options available in a freight config file
type Config ¶
type Config struct {
Base BaseConfig `mapstructure:"freight", hcl:"freight,squash"`
Projects []*Project `mapstructure:"project" hcl:"project"`
}
type Manager ¶
type Manager struct{}
Manager manages the resolving projects and tasks in a freight manafest
type ProgressBar ¶
type ProgressBar struct {
// contains filtered or unexported fields
}
ProgressBar wraps a github.com/cheggaaa/pb.Pool in order to display download progress for one or multiple downloads.
If two different instance of ProgressBar try to display a progress only one will be displayed. It is therefore recommended to use DefaultProgressBar
func (*ProgressBar) TrackProgress ¶
func (cpb *ProgressBar) TrackProgress(src string, currentSize, totalSize int64, stream io.ReadCloser) io.ReadCloser
TrackProgress instantiates a new progress bar that will display the progress of stream until closed. total can be 0.
Click to show internal directories.
Click to hide internal directories.